@@ -323,7 +323,7 @@ class Sequential():
         if live_stats == -1:
             update = 50
         elif live_stats == 0:
-            update = epochs
+            update = 1
         elif live_stats == 1 or live_stats == 2:
             update = 25
 
